@@ -27,7 +27,7 @@ int cat_main (int argc, char **argv) {
 		if (fd==-1) {
 /* If there is an error, print it and continue loop */
 			if ((fd=open(argv[i],O_RDONLY))<0) {
-				write(STDERR_FILENO, "rm: ", 4);
+				write(STDERR_FILENO, "cat: ", 5);
 				perror(argv[i]);
 				error_code=-1;
 				goto loop;
@@ -35,7 +35,7 @@ int cat_main (int argc, char **argv) {
 		}
 /* Read the file in 1024 byte sections until we encounter the end. */
 		while (1) {
-			if ((x=read(fd, &buf, 1024))==0) break;
+			if ((x=read(fd, &buf, 1024))<1) break;
 			write(STDOUT_FILENO, &buf, x);
 		}
 		close(fd);
