@@ -11,6 +11,8 @@
 #include "cp.h"
 #include "hostname.h"
 #include "sh.h"
+#include "mknod.h"
+#include "ps.h"
 
 int (*(commands_exec[256]))()={
 			ls_main,
@@ -26,6 +28,8 @@ int (*(commands_exec[256]))()={
 			cp_main,
 			hostname_main,
 			sh_main,
+			mknod_main,
+			ps_main,
 			NULL
 };
 
@@ -43,5 +47,7 @@ char *commands_name[256]={
 			"cp",
 			"hostname",
 			"sh",
+			"mknod",
+			"ps",
 			NULL
 };
