@@ -1,30 +1,31 @@
-#define __USE_BSD
+//#define __USE_BSD
 #include <stdio.h>
 #include <unistd.h>
 #include <stdlib.h>
-#include <dirent.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#include <dirent.h>
 #include "version.h"
 #include "ls.h"
 
-extern char **environ;
 
 int ls_main (int argc, char **argv) {
+	DIR *dirtype;
+	struct dirent *dinfo;
 	char pwd[256];
-	char buff[128];
-	off_t basep;
-	int fd;
 
-
-	strcpy(pwd,".");
-
-	if ((fd=open(pwd, O_RDONLY))<0) return(-1);
-	while (1) {
-		if (getdirentries(fd, buff, sizeof(buff), &basep)<1) break;
-		write(STDOUT_FILENO,&buff,sizeof(buff));
+	if (argc==1) {
+		strcpy(pwd,".");
+	} else {
+		strcpy(pwd,argv[1]);
 	}
-	close(fd);
+
+	if ((dirtype=opendir(pwd))==NULL) return(-1);
+	while (1) {
+		if ((dinfo=readdir(dirtype))==NULL) break;
+		printf("%s\n",dinfo->d_name);
+	}
+	closedir(dirtype);
 	return(0);
 }
