@@ -36,4 +36,4 @@ done
 if [ "$OPT" = "" ]; then
 	exit
 fi
-grep -v "\!" $TODOFILE | grep $OPT | cut -c 2-1000
+grep -v "\!" $TODOFILE | grep $OPT | cut -c 2-1000 | sort | cat -n
